

# Plot ordination
#
# Scaling 1 para el circulo de equilibrio
#
# Scl = 1 -> Unit Circle
# Scl = 2 -> grp with colours
# odh = T -> Ordihull for Scl = 2
#
plotPCA <- function(rdah,grp,scl=2,odh=F)
{
  require(vegan)
  # scl <- 1
  require(RColorBrewer)
  ngrp <- length(unique(grp))
  colvec <- brewer.pal(grp,"Set1")
  pchvec <- c(21:25,0:20)
  
  eig <- eigenvals(rdah)/sum(eigenvals(rdah))*100
  eig <- format(round(eig,0), digits = 1)
  plot(rdah, type = "n", scaling = scl,xlab=paste("Axis1 :",eig[1]),ylab=paste("Axis2 :",eig[2]))
  if(scl==2) {
    points(rdah, display = "sites", col = colvec[grp],
           scaling = scl, pch = pchvec[grp])
    legend("topright", legend = levels(grp), bty = "n",
           col = colvec, pch = pchvec, cex=1)
  }
  spe.sc <- scores(rdah, choices=1:2, display="sp",scaling=scl)
  arrows(0, 0, spe.sc[, 1], spe.sc[, 2], length=0, lty=1, col="darkgray")
  ordilabel(rdah,dis="sp",cex=1,col="darkgray",font=2,scaling=scl)
  if(scl==1) pcacircle(rdah)
  if(scl==2 & odh ) ordihull(rdah,grp,kind="se",conf=0.95,label=F,col="green")
  
}


plotNMDS <- function(rdah,grp,sp_nam,legt)
{
  require(vegan)
  # scl <- 1
  require(RColorBrewer)
  ngrp <- length(unique(grp))
  colvec <- brewer.pal(ngrp,"Set1")
  
  pchvec <- c(21:25,0:20)
  plot(rdah, type = "n",xlab="Axis1",ylab="Axis2")
  
  points(rdah, display = "sites", col = colvec[grp],pch = pchvec[grp],bg=colvec[grp])
  legend("topright", legend = levels(grp), title=legt, bty = "n",col = colvec, pch = pchvec, pt.bg=colvec , cex=1)

  #spe.sc <- scores(rdah, choices=1:2, display="sp",scaling=scl)
  #arrows(0, 0, spe.sc[, 1], spe.sc[, 2], length=0, lty=1, col="darkgray")
  spe.sc <- scores(rdah, choices=1:2, display="sp")
  arrows(0, 0, spe.sc[, 1], spe.sc[, 2], length=0, lty=1, col="black")
  ordilabel(rdah,dis="sp",cex=0.8,col="black")
  ordilabel(rdah,dis="sp",cex=1,col="darkgray",font=2,labels=sp_nam)
  ordihull(rdah,grp,kind="se",conf=0.95,label=F,draw="polygon",col="grey90")
}


# Ajusta y Plotea superficies de respuesta y envfit
#
plot_spcSurface <- function(rdam,speFram, speName, scal=2 )
{
  require(vegan)
  form <- as.formula(paste("rdam~",speName))
  ef <- envfit(form, data = speFram)
  sf <- ordisurf(form, data = speFram, plot = FALSE, scaling = scal)
  print(summary(sf))
  plot(rdam, type="po",scaling = scal)
  spe.sc <- scores(rdam, choices=1:2, display="sp",scaling = scal)
  arrows(0, 0, spe.sc[, 1], spe.sc[, 2], length=0, lty=1, col="red")
  ordilabel(rdam,dis="sp",cex=0.8,col="red",scaling = scal)
  plot(ef)
  plot(sf, col = "darkgreen", add = TRUE)
  
  return(data.frame(spe=speName,pval=summary(sf)$p.table[4]))
} 


plot_spcEnvfit <- function(rdam,ef,fac, pmax=0.05,scal=2)
{
  require(vegan)
  require(RColorBrewer)
  myCols <- brewer.pal(6,"Set1")
  #form <- as.formula(paste("rdam~",speName))
  #ef <- envfit(form, data = speFram)
  #sf <- ordisurf(form, data = speFram, plot = FALSE, scaling = scal)
  #print(summary(sf))
  plot(rdam, type="po" )
  spe.sc <- scores(rdam, choices=1:2, display="sp")
  arrows(0, 0, spe.sc[, 1], spe.sc[, 2], length=0, lty=1, col="red")
  ordilabel(rdam,dis="sp",cex=0.8,col="red")
  plot(ef,p.max = pmax)
  #plot(sf, col = "darkgreen", add = TRUE)
  
  #return(data.frame(spe=speName,pval=summary(sf)$p.table[4]))
} 


qr_coef_to_df <-function(sf,vnam){
  
  pp <-do.call(rbind,lapply(sf, coef))
  name <- rownames(pp)
  as.data.frame(pp,row.names = NULL,optional=F)
  rownames(pp)<-NULL
  pp<- data.frame(name,pp)
  names(pp)<-c("Varname","Value","Std.Err","tvalue","Pval")
  #pp<-pp[pp$Varname==vnam,]
  pp<-pp[grep(vnam,pp$Varname),]
  
  #pp$tau <- unlist(lapply(sf, "[[","tau"))
  pp$tau <-rep(unlist(lapply(sf, "[[","tau")),each=nrow(pp)/length(sf))
  
  return(pp)
}
